==> e107-0.7.20.tbz: www/e107/e107_plugins/content/languages/English/lan_content.php <==
<?php
/*
+ ----------------------------------------------------------------------------+
|     e107 website system - Language File.
|
|     $Source: /cvs_backup/e107_0.7/e107_plugins/content/languages/English/lan_content.php,v $
|     $Revision: 11346 $
|     $Date: 2010-02-17 13:56:14 -0500 (Wed, 17 Feb 2010) $
|     $Author: secretr $
+----------------------------------------------------------------------------+
*/


define("CONTENT_EMAILPRINT_LAN_1", "this content item is from");

define("POPUP_LAN_1", "click to enlarge image");

define("CONTENT_NOTIFY_LAN_1", "Content Events");
define("CONTENT_NOTIFY_LAN_2", "Content item submitted by user");
define("CONTENT_NOTIFY_LAN_3", "Content Submitted");

define("CONTENT_TYPE_LAN_0", "categories");
define("CONTENT_TYPE_LAN_1", "authors");
define("CONTENT_TYPE_LAN_2", "archive");
define("CONTENT_TYPE_LAN_3", "top rated");
define("CONTENT_TYPE_LAN_4", "top score");
define("CONTENT_TYPE_LAN_5", "recent");

define("CONTENT_ICON_LAN_0", "edit");
define("CONTENT_ICON_LAN_1", "delete");
define("CONTENT_ICON_LAN_2", "options");
define("CONTENT_ICON_LAN_3", "user details");
define("CONTENT_ICON_LAN_4", "download attachment");
define("CONTENT_ICON_LAN_5", "new");
define("CONTENT_ICON_LAN_6", "submit content");
define("CONTENT_ICON_LAN_7", "author list");
define("CONTENT_ICON_LAN_8", "warning");
define("CONTENT_ICON_LAN_9", "ok");
define("CONTENT_ICON_LAN_10", "error");
define("CONTENT_ICON_LAN_11", "order items in category");
define("CONTENT_ICON_LAN_12", "order items in main parent");
define("CONTENT_ICON_LAN_13", "personal admin");
define("CONTENT_ICON_LAN_14", "personal content manager");
define("CONTENT_ICON_LAN_15", "view");

define("CONTENT_ADMIN_DATE_LAN_0", "January");
define("CONTENT_ADMIN_DATE_LAN_1", "February");
define("CONTENT_ADMIN_DATE_LAN_2", "March");
define("CONTENT_ADMIN_DATE_LAN_3", "April");
define("CONTENT_ADMIN_DATE_LAN_4", "May");
define("CONTENT_ADMIN_DATE_LAN_5", "June");
define("CONTENT_ADMIN_DATE_LAN_6", "July");
define("CONTENT_ADMIN_DATE_LAN_7", "August");
define("CONTENT_ADMIN_DATE_LAN_8", "September");
define("CONTENT_ADMIN_DATE_LAN_9", "October");
define("CONTENT_ADMIN_DATE_LAN_10", "November");
define("CONTENT_ADMIN_DATE_LAN_11", "December");
define("CONTENT_ADMIN_DATE_LAN_12", "day");
define("CONTENT_ADMIN_DATE_LAN_13", "month");
define("CONTENT_ADMIN_DATE_LAN_14", "year");
define("CONTENT_ADMIN_DATE_LAN_15", "start date");
define("CONTENT_ADMIN_DATE_LAN_16", "end date");
define("CONTENT_ADMIN_DATE_LAN_17", "You can specify a start date for this content item. If you use a date in the future the content item will be visible from that point onward. If you do not need a specific starting date, you can just leave these fields as they are.");
define("CONTENT_ADMIN_DATE_LAN_18", "you can specify an end date for this content item. With the end date you can specify until which point in time the content item needs to be visible. If you do not need an end time for this content item, you can just leave the fields as they are.");

define("CONTENT_PAGETITLE_LAN_0", "Content");
define("CONTENT_PAGETITLE_LAN_1", "Main");
define("CONTENT_PAGETITLE_LAN_2", "Recent");
define("CONTENT_PAGETITLE_LAN_3", "Category");
define("CONTENT_PAGETITLE_LAN_4", "Top Rated");
define("CONTENT_PAGETITLE_LAN_5", "Author");
define("CONTENT_PAGETITLE_LAN_6", "Archive");
define("CONTENT_PAGETITLE_LAN_7", "Submit");
define("CONTENT_PAGETITLE_LAN_8", "Submit Content Item");
define("CONTENT_PAGETITLE_LAN_9", "Personal Content Manager");
define("CONTENT_PAGETITLE_LAN_10", "View Items");
define("CONTENT_PAGETITLE_LAN_11", "Edit Item");
define("CONTENT_PAGETITLE_LAN_12", "Create Item");
define("CONTENT_PAGETITLE_LAN_13", "Categories");
define("CONTENT_PAGETITLE_LAN_14", "Authorlist");
define("CONTENT_PAGETITLE_LAN_15", "Top Score");

define("CONTENT_SEARCH_LAN_0", "no content items found with these keywords.");

define("CONTENT_ORDER_LAN_0", "sort by ...");
define("CONTENT_ORDER_LAN_1", "heading (ASC)");
define("CONTENT_ORDER_LAN_2", "heading (DESC)");
define("CONTENT_ORDER_LAN_3", "date (ASC)");
define("CONTENT_ORDER_LAN_4", "date (DESC)");
define("CONTENT_ORDER_LAN_5", "refer (ASC)");
define("CONTENT_ORDER_LAN_6", "refer (DESC)");
define("CONTENT_ORDER_LAN_7", "parent (ASC)");
define("CONTENT_ORDER_LAN_8", "parent (DESC)");
define("CONTENT_ORDER_LAN_9", "order (ASC)");
define("CONTENT_ORDER_LAN_10", "order (DESC)");
define("CONTENT_ORDER_LAN_11", "author (ASC)");
define("CONTENT_ORDER_LAN_12", "author (DESC)");

define("CONTENT_LAN_0", "Content");
define("CONTENT_LAN_1", "Recent List");
define("CONTENT_LAN_2", "Category List");
define("CONTENT_LAN_3", "Category");
define("CONTENT_LAN_4", "Author List");
define("CONTENT_LAN_5", "Author");
define("CONTENT_LAN_6", "all categories");
define("CONTENT_LAN_7", "all authors");
define("CONTENT_LAN_8", "top rated items");
define("CONTENT_LAN_9", "in");
define("CONTENT_LAN_10", "on");
define("CONTENT_LAN_11", "by");
define("CONTENT_LAN_12", "top score items");
define("CONTENT_LAN_13", "list");
define("CONTENT_LAN_14", "-- categories --");
define("CONTENT_LAN_15", "no authors yet");
define("CONTENT_LAN_16", "[read more]");
define("CONTENT_LAN_17", "");
define("CONTENT_LAN_18", "search by keyword");
define("CONTENT_LAN_19", "search");
define("CONTENT_LAN_20", "content search results");
define("CONTENT_LAN_21", "no content types yet.");
define("CONTENT_LAN_22", "content types");
define("CONTENT_LAN_23", "Recent Content List");
define("CONTENT_LAN_24", "breadcrumb");
define("CONTENT_LAN_25", "Content Categories");
define("CONTENT_LAN_26", "Content Category");
define("CONTENT_LAN_27", "subcategories");
define("CONTENT_LAN_28", "parent subcategories");
define("CONTENT_LAN_29", "unknown");
define("CONTENT_LAN_30", "content item");
define("CONTENT_LAN_31", "content items");
define("CONTENT_LAN_32", "Content Author List");
define("CONTENT_LAN_33", "Go To Page");
define("CONTENT_LAN_34", "content");
define("CONTENT_LAN_35", "comments");
define("CONTENT_LAN_36", "moderate comments");
define("CONTENT_LAN_37", "no content items rated yet");
define("CONTENT_LAN_38", "Top Rated Content");
define("CONTENT_LAN_39", "author list");
define("CONTENT_LAN_40", "author user details");
define("CONTENT_LAN_41", "attached");
define("CONTENT_LAN_42", "file");
define("CONTENT_LAN_43", "files");
define("CONTENT_LAN_44", "hits:");
define("CONTENT_LAN_45", "author awarded score:");
define("CONTENT_LAN_46", "article index");
define("CONTENT_LAN_47", "author");
define("CONTENT_LAN_48", "content items");
define("CONTENT_LAN_49", "last content item");
define("CONTENT_LAN_50", "date");
define("CONTENT_LAN_51", "Type List");
define("CONTENT_LAN_52", "no valid authors found");
define("CONTENT_LAN_53", "item");
define("CONTENT_LAN_54", "items");
define("CONTENT_LAN_55", "last item on");
define("CONTENT_LAN_56", "show overview of");
define("CONTENT_LAN_57", "comments:");
define("CONTENT_LAN_58", "home");
define("CONTENT_LAN_59", "content");
define("CONTENT_LAN_60", "recent");
define("CONTENT_LAN_61", "view recent items");
define("CONTENT_LAN_62", "view all categories");
define("CONTENT_LAN_63", "view all authors");
define("CONTENT_LAN_64", "view top rated items");
define("CONTENT_LAN_65", "submit content");
define("CONTENT_LAN_66", "click here to submit content, you can choose the category on the submit page.");
define("CONTENT_LAN_67", "personal content manager");
define("CONTENT_LAN_68", "click here to manage your personal content.");
define("CONTENT_LAN_69", "email the");
define("CONTENT_LAN_70", "print the");
define("CONTENT_LAN_71", "content item");
define("CONTENT_LAN_72", "category item");
define("CONTENT_LAN_73", "no content items yet");
define("CONTENT_LAN_74", "");
define("CONTENT_LAN_75", "submit content item");
define("CONTENT_LAN_76", "create pdf file of the");
define("CONTENT_LAN_77", "content search");
define("CONTENT_LAN_78", "untitled page");
define("CONTENT_LAN_79", "page");
define("CONTENT_LAN_80", "recent items : ");
define("CONTENT_LAN_81", "categories");
define("CONTENT_LAN_82", "no items yet in");
define("CONTENT_LAN_83", "item archive");
define("CONTENT_LAN_84", "Content Archive");
define("CONTENT_LAN_85", "authorlist");
define("CONTENT_LAN_86", "view top score items");
define("CONTENT_LAN_87", "Top Score Content");
define("CONTENT_LAN_88", "no content items have a score yet");
define("CONTENT_LAN_89", "select page");
define("CONTENT_LAN_90", "previous page");
define("CONTENT_LAN_91", "next page");
define("CONTENT_LAN_92", " - current");

define('CONTENT_LAN_ALL', 'all');

define("CONTENT_MENU_LAN_0", "content Menu :");
define("CONTENT_MENU_LAN_1", "no content items yet");
define("CONTENT_MENU_LAN_2", "recent items");
define("CONTENT_MENU_LAN_3", "categories");
define("CONTENT_MENU_LAN_4", "content links");
define("CONTENT_MENU_LAN_5", "no items in");
define("CONTENT_MENU_LAN_6", "");
define("CONTENT_MENU_LAN_7", "");
define("CONTENT_MENU_LAN_8", "");
define("CONTENT_MENU_LAN_9", "");
define("CONTENT_MENU_LAN_10", "");
define("CONTENT_MENU_LAN_11", "");
define("CONTENT_MENU_LAN_12", "");
define("CONTENT_MENU_LAN_13", "");
define("CONTENT_MENU_LAN_14", "");
define("CONTENT_MENU_LAN_15", "");
define("CONTENT_MENU_LAN_16", "");
define("CONTENT_MENU_LAN_17", "");
define("CONTENT_MENU_LAN_18", "");
define("CONTENT_MENU_LAN_19", "");
define("CONTENT_MENU_LAN_20", "");

?>

==> e107-1.0.3.tbz: www/e107/e107_plugins/content/languages/English/lan_content.php <==
<?php
/*
+ ----------------------------------------------------------------------------+
|     e107 website system - Language File.
|
|     $URL: https://e107.svn.sourceforge.net/svnroot/e107/trunk/e107_0.7/e107_plugins/content/languages/English/lan_content.php $
|     $Revision: 11678 $
|     $Id: lan_content.php 11678 2010-08-22 00:43:45Z e107coders $
|     $Author: e107coders $
+----------------------------------------------------------------------------+
*/


define("CONTENT_EMAILPRINT_LAN_1", "this content item is from");

define("POPUP_LAN_1", "click to enlarge image");

define("CONTENT_NOTIFY_LAN_1", "Content Events");
define("CONTENT_NOTIFY_LAN_2", "Content item submitted by user");
define("CONTENT_NOTIFY_LAN_3", "Content Submitted");

define("CONTENT_TYPE_LAN_0", "categories");
define("CONTENT_TYPE_LAN_1", "authors");
define("CONTENT_TYPE_LAN_2", "archive");
define("CONTENT_TYPE_LAN_3", "top rated");
define("CONTENT_TYPE_LAN_4", "top score");
define("CONTENT_TYPE_LAN_5", "recent");

define("CONTENT_ICON_LAN_0", "edit");
define("CONTENT_ICON_LAN_1", "delete");
define("CONTENT_ICON_LAN_2", "options");
define("CONTENT_ICON_LAN_3", "user details");
define("CONTENT_ICON_LAN_4", "download attachment");
define("CONTENT_ICON_LAN_5", "new");
define("CONTENT_ICON_LAN_6", "submit content");
define("CONTENT_ICON_LAN_7", "author list");
define("CONTENT_ICON_LAN_8", "warning");
define("CONTENT_ICON_LAN_9", "ok");
define("CONTENT_ICON_LAN_10", "error");
define("CONTENT_ICON_LAN_11", "order items in category");
define("CONTENT_ICON_LAN_12", "order items in main parent");
define("CONTENT_ICON_LAN_13", "personal admin");
define("CONTENT_ICON_LAN_14", "personal content manager");
define("CONTENT_ICON_LAN_15", "view");

define("CONTENT_ADMIN_DATE_LAN_0", "January");
define("CONTENT_ADMIN_DATE_LAN_1", "February");
define("CONTENT_ADMIN_DATE_LAN_2", "March");
define("CONTENT_ADMIN_DATE_LAN_3", "April");
define("CONTENT_ADMIN_DATE_LAN_4", "May");
define("CONTENT_ADMIN_DATE_LAN_5", "June");
define("CONTENT_ADMIN_DATE_LAN_6", "July");
define("CONTENT_ADMIN_DATE_LAN_7", "August");
define("CONTENT_ADMIN_DATE_LAN_8", "September");
define("CONTENT_ADMIN_DATE_LAN_9", "October");
define("CONTENT_ADMIN_DATE_LAN_10", "November");
define("CONTENT_ADMIN_DATE_LAN_11", "December");
define("CONTENT_ADMIN_DATE_LAN_12", "day");
define("CONTENT_ADMIN_DATE_LAN_13", "month");
define("CONTENT_ADMIN_DATE_LAN_14", "year");
define("CONTENT_ADMIN_DATE_LAN_15", "start date");
define("CONTENT_ADMIN_DATE_LAN_16", "end date");
define("CONTENT_ADMIN_DATE_LAN_17", "You can specify a start date for this content item. If you use a date in the future the content item will be visible from that point onward. If you do not need a specific starting date, you can just leave these fields as they are.");
define("CONTENT_ADMIN_DATE_LAN_18", "you can specify an end date for this content item. With the end date you can specify until which point in time the content item needs to be visible. If you do not need an end time for this content item, you can just leave the fields as they are.");

define("CONTENT_PAGETITLE_LAN_0", "Content");
define("CONTENT_PAGETITLE_LAN_1", "Main");
define("CONTENT_PAGETITLE_LAN_2", "Recent");
define("CONTENT_PAGETITLE_LAN_3", "Category");
define("CONTENT_PAGETITLE_LAN_4", "Top Rated");
define("CONTENT_PAGETITLE_LAN_5", "Author");
define("CONTENT_PAGETITLE_LAN_6", "Archive");
define("CONTENT_PAGETITLE_LAN_7", "Submit");
define("CONTENT_PAGETITLE_LAN_8", "Submit Content Item");
define("CONTENT_PAGETITLE_LAN_9", "Personal Content Manager");
define("CONTENT_PAGETITLE_LAN_10", "View Items");
define("CONTENT_PAGETITLE_LAN_11", "Edit Item");
define("CONTENT_PAGETITLE_LAN_12", "Create Item");
define("CONTENT_PAGETITLE_LAN_13", "Categories");
define("CONTENT_PAGETITLE_LAN_14", "Authorlist");
define("CONTENT_PAGETITLE_LAN_15", "Top Score");

define("CONTENT_SEARCH_LAN_0", "no content items found with these keywords.");

define("CONTENT_ORDER_LAN_0", "sort by ...");
define("CONTENT_ORDER_LAN_1", "heading (ASC)");
define("CONTENT_ORDER_LAN_2", "heading (DESC)");
define("CONTENT_ORDER_LAN_3", "date (ASC)");
define("CONTENT_ORDER_LAN_4", "date (DESC)");
define("CONTENT_ORDER_LAN_5", "refer (ASC)");
define("CONTENT_ORDER_LAN_6", "refer (DESC)");
define("CONTENT_ORDER_LAN_7", "parent (ASC)");
define("CONTENT_ORDER_LAN_8", "parent (DESC)");
define("CONTENT_ORDER_LAN_9", "order (ASC)");
define("CONTENT_ORDER_LAN_10", "order (DESC)");
define("CONTENT_ORDER_LAN_11", "author (ASC)");
define("CONTENT_ORDER_LAN_12", "author (DESC)");

define("CONTENT_LAN_0", "Content");
define("CONTENT_LAN_1", "Recent List");
define("CONTENT_LAN_2", "Category List");
define("CONTENT_LAN_3", "Category");
define("CONTENT_LAN_4", "Author List");
define("CONTENT_LAN_5", "Author");
define("CONTENT_LAN_6", "all categories");
define("CONTENT_LAN_7", "all authors");
define("CONTENT_LAN_8", "top rated items");
define("CONTENT_LAN_9", "in");
define("CONTENT_LAN_10", "on");
define("CONTENT_LAN_11", "by");
define("CONTENT_LAN_12", "top score items");
define("CONTENT_LAN_13", "list");
define("CONTENT_LAN_14", "-- categories --");
define("CONTENT_LAN_15", "no authors yet");
define("CONTENT_LAN_16", "[read more]");
define("CONTENT_LAN_17", "");
define("CONTENT_LAN_18", "search by keyword");
define("CONTENT_LAN_19", "search");
define("CONTENT_LAN_20", "content search results");
define("CONTENT_LAN_21", "no content types yet.");
define("CONTENT_LAN_22", "content types");
define("CONTENT_LAN_23", "Recent Content List");
define("CONTENT_LAN_24", "breadcrumb");
define("CONTENT_LAN_25", "Content Categories");
define("CONTENT_LAN_26", "Content Category");
define("CONTENT_LAN_27", "subcategories");
define("CONTENT_LAN_28", "parent subcategories");
define("CONTENT_LAN_29", "unknown");
define("CONTENT_LAN_30", "content item");
define("CONTENT_LAN_31", "content items");
define("CONTENT_LAN_32", "Content Author List");
define("CONTENT_LAN_33", "Go To Page");
define("CONTENT_LAN_34", "content");
define("CONTENT_LAN_35", "comments");
define("CONTENT_LAN_36", "moderate comments");
define("CONTENT_LAN_37", "no content items rated yet");
define("CONTENT_LAN_38", "Top Rated Content");
define("CONTENT_LAN_39", "author list");
define("CONTENT_LAN_40", "author user details");
define("CONTENT_LAN_41", "attached");
define("CONTENT_LAN_42", "file");
define("CONTENT_LAN_43", "files");
define("CONTENT_LAN_44", "hits:");
define("CONTENT_LAN_45", "author awarded score:");
define("CONTENT_LAN_46", "article index");
define("CONTENT_LAN_47", "author");
define("CONTENT_LAN_48", "content items");
define("CONTENT_LAN_49", "last content item");
define("CONTENT_LAN_50", "date");
define("CONTENT_LAN_51", "Type List");
define("CONTENT_LAN_52", "no valid authors found");
define("CONTENT_LAN_53", "item");
define("CONTENT_LAN_54", "items");
define("CONTENT_LAN_55", "last item on");
define("CONTENT_LAN_56", "show overview of");
define("CONTENT_LAN_57", "comments:");
define("CONTENT_LAN_58", "home");
define("CONTENT_LAN_59", "content");
define("CONTENT_LAN_60", "recent");
define("CONTENT_LAN_61", "view recent items");
define("CONTENT_LAN_62", "view all categories");
define("CONTENT_LAN_63", "view all authors");
define("CONTENT_LAN_64", "view top rated items");
define("CONTENT_LAN_65", "submit content");
define("CONTENT_LAN_66", "click here to submit content, you can choose the category on the submit page.");
define("CONTENT_LAN_67", "personal content manager");
define("CONTENT_LAN_68", "click here to manage your personal content.");
define("CONTENT_LAN_69", "email the");
define("CONTENT_LAN_70", "print the");
define("CONTENT_LAN_71", "content item");
define("CONTENT_LAN_72", "category item");
define("CONTENT_LAN_73", "no content items yet");
define("CONTENT_LAN_74", "");
define("CONTENT_LAN_75", "submit content item");
define("CONTENT_LAN_76", "create pdf file of the");
define("CONTENT_LAN_77", "content search");
define("CONTENT_LAN_78", "untitled page");
define("CONTENT_LAN_79", "page");
define("CONTENT_LAN_80", "recent items : ");
define("CONTENT_LAN_81", "categories");
define("CONTENT_LAN_82", "no items yet in");
define("CONTENT_LAN_83", "item archive");
define("CONTENT_LAN_84", "Content Archive");
define("CONTENT_LAN_85", "authorlist");
define("CONTENT_LAN_86", "view top score items");
define("CONTENT_LAN_87", "Top Score Content");
define("CONTENT_LAN_88", "no content items have a score yet");
define("CONTENT_LAN_89", "select page");
define("CONTENT_LAN_90", "previous page");
define("CONTENT_LAN_91", "next page");
define("CONTENT_LAN_92", " - current");

define('CONTENT_LAN_ALL', 'all');

define("CONTENT_MENU_LAN_0", "content Menu :");
define("CONTENT_MENU_LAN_1", "no content items yet");
define("CONTENT_MENU_LAN_2", "recent items");
define("CONTENT_MENU_LAN_3", "categories");
define("CONTENT_MENU_LAN_4", "content links");
define("CONTENT_MENU_LAN_5", "no items in");
define("CONTENT_MENU_LAN_6", "");
define("CONTENT_MENU_LAN_7", "");
define("CONTENT_MENU_LAN_8", "");
define("CONTENT_MENU_LAN_9", "");
define("CONTENT_MENU_LAN_10", "");
define("CONTENT_MENU_LAN_11", "");
define("CONTENT_MENU_LAN_12", "");
define("CONTENT_MENU_LAN_13", "");
define("CONTENT_MENU_LAN_14", "");
define("CONTENT_MENU_LAN_15", "");
define("CONTENT_MENU_LAN_16", "");
define("CONTENT_MENU_LAN_17", "");
define("CONTENT_MENU_LAN_18", "");
define("CONTENT_MENU_LAN_19", "");
define("CONTENT_MENU_LAN_20", "");

?>
